import React from 'react';
import { ColorPalette, getSelectedRowAndColumnFromPalette, highlightColorPalette } from '@atlaskit/editor-common/ui-color';
import { ArrowKeyNavigationType, DropdownContainer as Dropdown } from '@atlaskit/editor-common/ui-menu';
import { hexToEditorTextBackgroundPaletteColor } from '@atlaskit/editor-palette';
import { akEditorMenuZIndex } from '@atlaskit/editor-shared-styles';
export const PaletteDropdown = props => {
  const {
    popupsMountPoint,
    popupsBoundariesElement,
    popupsScrollableElement,
    isOpen,
    activeColor,
    trigger,
    onColorChange,
    isOpenedByKeyboard,
    handleClickOutside,
    handleEscapeKeydown
  } = props;

  // pixels, used to determine where to horizontally position the dropdown when space is limited
  // this should reflect the width of the dropdown when fully populated with colors, including translations due to layering
  const fitWidth = 242;
  const {
    selectedRowIndex,
    selectedColumnIndex
  } = getSelectedRowAndColumnFromPalette(highlightColorPalette, activeColor);
  return /*#__PURE__*/React.createElement(Dropdown, {
    mountTo: popupsMountPoint,
    boundariesElement: popupsBoundariesElement,
    scrollableElement: popupsScrollableElement,
    isOpen: isOpen,
    handleClickOutside: handleClickOutside,
    handleEscapeKeydown: handleEscapeKeydown,
    zIndex: akEditorMenuZIndex,
    fitWidth: fitWidth,
    closeOnTab: true,
    arrowKeyNavigationProviderOptions: {
      type: ArrowKeyNavigationType.COLOR,
      selectedRowIndex,
      selectedColumnIndex,
      isOpenedByKeyboard,
      isPopupPositioned: true
    },
    trigger: trigger
  }, /*#__PURE__*/React.createElement("div", {
    "data-testid": "highlight-color-palette"
  }, /*#__PURE__*/React.createElement(ColorPalette, {
    onClick: onColorChange,
    selectedColor: activeColor,
    paletteOptions: {
      palette: highlightColorPalette,
      hexToPaletteColor: hexToEditorTextBackgroundPaletteColor
    }
  })));
};